summaryrefslogtreecommitdiffstats
path: root/src/gui/editors/notation/NoteStyle.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/editors/notation/NoteStyle.h')
-rw-r--r--src/gui/editors/notation/NoteStyle.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/gui/editors/notation/NoteStyle.h b/src/gui/editors/notation/NoteStyle.h
index 3959e01..4431c16 100644
--- a/src/gui/editors/notation/NoteStyle.h
+++ b/src/gui/editors/notation/NoteStyle.h
@@ -99,8 +99,8 @@ public:
protected:
struct NoteDescription {
- NoteHeadShape shape; // if CustomCharName, use charName
- CharName charName; // only used if shape == CustomCharName
+ NoteHeadShape tqshape; // if CustomCharName, use charName
+ CharName charName; // only used if tqshape == CustomCharName
bool filled;
bool stem;
int flags;
@@ -109,14 +109,14 @@ protected:
VFixPoint vfix;
NoteDescription() :
- shape(AngledOval), charName(NoteCharacterNames::UNKNOWN),
+ tqshape(AngledOval), charName(NoteCharacterNames::UNKNOWN),
filled(true), stem(true), flags(0), slashes(0),
hfix(Normal), vfix(Middle) { }
- NoteDescription(NoteHeadShape _shape, CharName _charName,
+ NoteDescription(NoteHeadShape _tqshape, CharName _charName,
bool _filled, bool _stem, int _flags, int _slashes,
HFixPoint _hfix, VFixPoint _vfix) :
- shape(_shape), charName(_charName),
+ tqshape(_tqshape), charName(_charName),
filled(_filled), stem(_stem), flags(_flags), slashes(_slashes),
hfix(_hfix), vfix(_vfix) { }
};